<?php
/**
 * The template for displaying collection items
 *
 * @package WEN_Travel
 */

$enable = get_theme_mod( 'wen_travel_collection_option', 'disabled' );

if ( ! wen_travel_check_section( $enable ) ) {
	// Bail if collection section is disabled.
	return;
}

$wen_travel_type        = get_theme_mod( 'wen_travel_collection_type', 'category' );
$wen_travel_title       = get_theme_mod( 'wen_travel_collection_title');
$wen_travel_description = get_theme_mod( 'wen_travel_collection_description' );

if ( ! $wen_travel_title && ! $wen_travel_description ) {
	$classes[] = 'no-section-heading';
}

$layout = get_theme_mod( 'wen_travel_collection_layout', 'layout-three' );

$classes[] = $layout;
$classes[] = $wen_travel_type;
$classes[] = 'section';

if ( get_theme_mod( 'wen_travel_collection_bg_image' ) ) {
	$classes[] = 'has-background-image';
}
?>

<div id="portfolio-content-section" class="portfolio-content-section <?php echo esc_attr( implode( ' ', $classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $wen_travel_title || $wen_travel_description ) : ?>
			<div class="section-heading-wrapper">
				<?php if ( $wen_travel_title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"wen_travel_><?php echo wp_kses_post( $wen_travel_title ); ?></h2>
					</div><!-- .page-title-wrapper -->
				<?php endif; ?>

				<?php if ( $wen_travel_description ) : ?>
					<div class="section-description">
						<p>
							<?php
								echo wp_kses_post( $wen_travel_description );
							?>
						</p>
					</div><!-- .section-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="section-content-wrapper portfolio-content-wrapper <?php echo esc_attr( $layout ); ?>">

			<?php if ( 'category' === $wen_travel_type && ! empty( $cats = get_theme_mod( 'wen_travel_collection_select_category' ) ) ) : ?>
			<div class="filter-button-group button-group">
				<button class="button is-checked" data-filter="*"><?php esc_html_e( 'Show All', 'wen-travel-pro' ) ?></button>
				<?php
				foreach ( $cats as $wen_travel_cat ) {
					$catinfo = get_category( $wen_travel_cat );
					?>
					<button class="button" data-filter=".category-<?php echo esc_attr( $catinfo->slug ); ?>"><?php echo esc_html( $catinfo->name ); ?></button>
					<?php
				}
			    ?>
			</div>
			<?php endif;?>

			<div class="grid">
				<?php
				if ( 'custom' === $wen_travel_type ) {
					get_template_part( 'template-parts/collection/image', 'collection' );
				} else {
					get_template_part( 'template-parts/collection/post-types', 'collection' );
				}
				?>
			</div><!-- .grid -->
		</div><!-- .section-content-wrap -->

		<?php
			$target          = get_theme_mod( 'wen_travel_collection_target' ) ? '_blank': '_self';
			$wen_travel_link = get_theme_mod( 'wen_travel_collection_link', '#' );
			$text            = get_theme_mod( 'wen_travel_collection_text' );

			if ( $text ) :
		?>

		<p class="view-more">
			<a class="button" target="<?php echo $target; ?>" href="<?php echo esc_url( $wen_travel_link ); ?>"><?php echo esc_html( $text ); ?></a>
		</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- #collection-section -->
